(v1.11.5)=
### 1.11.5 {small}`2025-10-20`

#### Documentation

- Add {doc}`/how-to/cell-cycle` {smaller}`P Angerer` ({pr}`3816`)

#### Bug fixes

- Deprecate `__version__` and use standard {func}`~importlib.metadata.version` API {smaller}`P Angerer` ({pr}`3811`)

#### Performance

- Optimise {func}`scanpy.pp.highly_variable_genes` with `batch_key` set for dask arrays {smaller}`M Mueller` ({pr}`3735`)
